@@ -13,7 +13,7 @@ use Modern::Perl;    ## no critic (UselessNoCritic,RequireExplicitPackage)
 package XML::Ant::BuildFile::Element::Arg;
 
 BEGIN {
-    $XML::Ant::BuildFile::Element::Arg::VERSION = '0.212';
+    $XML::Ant::BuildFile::Element::Arg::VERSION = '0.213';
 }
 
 # ABSTRACT: Argument element for a task in an Ant build file
@@ -64,7 +64,8 @@ __PACKAGE__->meta->make_immutable();
 
 =pod
 
-=for :stopwords Mark Gardner GSI Commerce
+=for :stopwords Mark Gardner GSI Commerce cpan testmatrix url annocpan anno bugtracker rt
+cpants kwalitee diff irc mailto metadata placeholders
 
 =encoding utf8
 
@@ -74,7 +75,7 @@ XML::Ant::BuildFile::Element::Arg - Argument element for a task in an Ant build
 
 =head1 VERSION
 
-version 0.212
+version 0.213
 
 =head1 SYNOPSIS
 
@@ -115,14 +116,86 @@ handles C<< <arg/> >> elements with the following attributes:
 
 =back
 
-=head1 BUGS
+=head1 SUPPORT
 
-Please report any bugs or feature requests on the bugtracker website
-http://github.com/mjgardner/XML-Ant-BuildFile/issues
+=head2 Perldoc
 
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
+You can find documentation for this module with the perldoc command.
+
+  perldoc XML::Ant::BuildFile
+
+=head2 Websites
+
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
+
+=over 4
+
+=item *
+
+Search CPAN
+
+L<http://search.cpan.org/dist/XML-Ant-BuildFile>
+
+=item *
+
+RT: CPAN's Bug Tracker
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=XML-Ant-BuildFile>
+
+=item *
+
+AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/XML-Ant-BuildFile>
+
+=item *
+
+CPAN Ratings
+
+L<http://cpanratings.perl.org/d/XML-Ant-BuildFile>
+
+=item *
+
+CPAN Forum
+
+L<http://cpanforum.com/dist/XML-Ant-BuildFile>
+
+=item *
+
+CPANTS Kwalitee
+
+L<http://cpants.perl.org/dist/overview/XML-Ant-BuildFile>
+
+=item *
+
+CPAN Testers Results
+
+L<http://cpantesters.org/distro/X/XML-Ant-BuildFile.html>
+
+=item *
+
+CPAN Testers Matrix
+
+L<http://matrix.cpantesters.org/?dist=XML-Ant-BuildFile>
+
+=back
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests through the web
+interface at L<https://github.com/mjgardner/xml-ant-buildfile/issues>. You will be automatically notified of any
+progress on the request by the system.
+
+=head2 Source Code
+
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
+
+L<https://github.com/mjgardner/xml-ant-buildfile>
+
+  git clone git://github.com/mjgardner/xml-ant-buildfile.git
 
 =head1 AUTHOR
 
